==> ispconfig3_billing_addon_1.1.zip: billing/interface/web/billing/form/invoice_item_template.tform.php <==
<?php

/*
Copyright (c) 2010, Till Brehm, projektfarm Gmbh
All rights reserved.
*/

/*
	Form Definition

	Tabledefinition

	Datatypes:
	- INTEGER (Forces the input to Int)
	- DOUBLE
	- CURRENCY (Formats the values to currency notation)
	- VARCHAR (no format check, maxlength: 255)
	- TEXT (no format check)
	- DATE (Dateformat, automatic conversion to timestamps)

	Formtype:
	- TEXT (Textfield)
	- TEXTAREA (Textarea)
	- PASSWORD (Password textfield, input is not shown when edited)
	- SELECT (Select option field)
	- RADIO
	- CHECKBOX
	- CHECKBOXARRAY
	- FILE

	VALUE:
	- Wert oder Array

	Hint:
	The ID field of the database table is not part of the datafield definition.
	The ID field must be always auto incement (int or bigint).


*/

$form["title"] 			= "Invoice item Template";
$form["description"] 	= "";
$form["name"] 			= "invoice_item_template";
$form["action"]			= "invoice_item_template_edit.php";
$form["db_table"]		= "invoice_item_template";
$form["db_table_idx"]	= "invoice_item_template_id";
$form["db_history"]		= "no";
$form["tab_default"]	= "item";
$form["list_default"]	= "invoice_item_template_list.php";
$form["auth"]			= 'yes';

$form["auth_preset"]["userid"]  = 0; // 0 = id of the user, > 0 id must match with id of current user
$form["auth_preset"]["groupid"] = 0; // 0 = default groupid of the user, > 0 id must match with groupid of current user
$form["auth_preset"]["perm_user"] = 'riud'; //r = read, i = insert, u = update, d = delete
$form["auth_preset"]["perm_group"] = 'riud'; //r = read, i = insert, u = update, d = delete
$form["auth_preset"]["perm_other"] = ''; //r = read, i = insert, u = update, d = delete


$form["tabs"]['item'] = array (
	'title' 	=> "Item",
	'width' 	=> 100,
	'template' 	=> "templates/invoice_item_template_item.htm",
	'fields' 	=> array (
	##################################
	# Begin Datatable fields
	##################################
		'type' => array (
			'datatype'	=> 'VARCHAR',
			'formtype'	=> 'SELECT',
			'default'	=> 'default',
			'value'		=> array('Item' => 'Item','Recurring' => 'Recurring','Service' => 'Service'),
			'separator'	=> '',
			'width'		=> '30',
			'maxlength'	=> '255',
			'rows'		=> '',
			'cols'		=> ''
		),
		'name' => array (
			'datatype'	=> 'VARCHAR',
			'formtype'	=> 'TEXT',
			'validators'	=> array ( 	0 => array (	'type'	=> 'NOTEMPTY',
														'errmsg'=> 'name_error_empty'),
										),
			'default'	=> '',
			'value'		=> '',
			'separator'	=> '',
			'width'		=> '30',
			'maxlength'	=> '255',
			'rows'		=> '',
			'cols'		=> ''
		),
		'description' => array (
			'datatype'	=> 'TEXT',
			'formtype'	=> 'TEXTAREA',
			'default'	=> '',
			'value'		=> '',
			'separator'	=> '',
			'width'		=> '',
			'maxlength'	=> '',
			'rows'		=> '10',
			'cols'		=> '30'
		),
		'price' => array (
			'datatype'	=> 'CURRENCY',
			'formtype'	=> 'TEXT',
			'validators'	=> array ( 	0 => array (	'type'	=> 'NOTEMPTY',
														'errmsg'=> 'price_error_empty'),
										),
			'default'	=> '',
			'value'		=> '',
			'separator'	=> '',
			'width'		=> '10',
			'maxlength'	=> '255',
			'rows'		=> '',
			'cols'		=> ''
		),
		'vat' => array (
			'datatype'	=> 'CURRENCY',
			'formtype'	=> 'TEXT',
			'default'	=> '',
			'value'		=> '',
			'separator'	=> '',
			'width'		=> '5',
			'maxlength'	=> '5',
			'rows'		=> '',
			'cols'		=> ''
		),
		'unit' => array (
			'datatype'	=> 'VARCHAR',
			'formtype'	=> 'SELECT',
			'default'	=> 'default',
			'value'		=> array('Item' => 'Item','Hour' => 'Hour','Half-hour' => 'Half-hour'),
			'separator'	=> '',
			'width'		=> '30',
			'maxlength'	=> '255',
			'rows'		=> '',
			'cols'		=> ''
		),
		'recur_months' => array (
			'datatype'	=> 'INTEGER',
			'formtype'	=> 'TEXT',
			'default'	=> '',
			'value'		=> '',
			'separator'	=> '',
			'width'		=> '3',
			'maxlength'	=> '3',
			'rows'		=> '',
			'cols'		=> ''
		),
		'client_template_id' => array (
			'datatype'	=> 'INTEGER',

			'formtype'	=> 'SELECT',
			'default'	=> '',
			'datasource'	=> array ( 	'type'	=> 'SQL',
										'querystring' => "SELECT template_id,template_name FROM client_template ORDER BY template_name",
										'keyfield'=> 'template_id',
										'valuefield'=> 'template_name'
									 ),
			'value'		=> array(0 => '-- None --')
		),
	##################################
	# END Datatable fields
	##################################
	)
);


?>

==> ispconfig3_billing_addon_1.3.zip: billing/interface/web/billing/form/invoice_item_template.tform.php <==
<?php

/*
Copyright (c) 2010, Till Brehm, projektfarm Gmbh
All rights reserved.
*/

/*
	Form Definition

	Tabledefinition

	Datatypes:
	- INTEGER (Forces the input to Int)
	- DOUBLE
	- CURRENCY (Formats the values to currency notation)
	- VARCHAR (no format check, maxlength: 255)
	- TEXT (no format check)
	- DATE (Dateformat, automatic conversion to timestamps)

	Formtype:
	- TEXT (Textfield)
	- TEXTAREA (Textarea)
	- PASSWORD (Password textfield, input is not shown when edited)
	- SELECT (Select option field)
	- RADIO
	- CHECKBOX
	- CHECKBOXARRAY
	- FILE

	VALUE:
	- Wert oder Array

	Hint:
	The ID field of the database table is not part of the datafield definition.
	The ID field must be always auto incement (int or bigint).


*/

$form["title"] 			= "Invoice item Template";
$form["description"] 	= "";
$form["name"] 			= "invoice_item_template";
$form["action"]			= "invoice_item_template_edit.php";
$form["db_table"]		= "invoice_item_template";
$form["db_table_idx"]	= "invoice_item_template_id";
$form["db_history"]		= "no";
$form["tab_default"]	= "item";
$form["list_default"]	= "invoice_item_template_list.php";
$form["auth"]			= 'yes';

$form["auth_preset"]["userid"]  = 0; // 0 = id of the user, > 0 id must match with id of current user
$form["auth_preset"]["groupid"] = 0; // 0 = default groupid of the user, > 0 id must match with groupid of current user
$form["auth_preset"]["perm_user"] = 'riud'; //r = read, i = insert, u = update, d = delete
$form["auth_preset"]["perm_group"] = 'riud'; //r = read, i = insert, u = update, d = delete
$form["auth_preset"]["perm_other"] = ''; //r = read, i = insert, u = update, d = delete

$form["tabs"]['item'] = array (
	'title' 	=> "Item",
	'width' 	=> 100,
	'template' 	=> "templates/invoice_item_template_item.htm",
	'fields' 	=> array (
	##################################
	# Begin Datatable fields
	##################################
		'type' => array (
			'datatype'	=> 'VARCHAR',
			'formtype'	=> 'SELECT',
			'default'	=> 'default',
			'value'		=> array('Item' => 'Item','Recurring' => 'Recurring','Service' => 'Service'),
			'separator'	=> '',
			'width'		=> '30',
			'maxlength'	=> '255',
			'rows'		=> '',
			'cols'		=> ''
		),
		'name' => array (
			'datatype'	=> 'VARCHAR',
			'formtype'	=> 'TEXT',
			'validators'	=> array ( 	0 => array (	'type'	=> 'NOTEMPTY',
														'errmsg'=> 'name_error_empty'),
										),
			'default'	=> '',
			'value'		=> '',
			'separator'	=> '',
			'width'		=> '30',
			'maxlength'	=> '255',
			'rows'		=> '',
			'cols'		=> ''
		),
		'description' => array (
			'datatype'	=> 'TEXT',
			'formtype'	=> 'TEXTAREA',
			'default'	=> '',
			'value'		=> '',
			'separator'	=> '',
			'width'		=> '',
			'maxlength'	=> '',
			'rows'		=> '10',
			'cols'		=> '30'
		),
		'price' => array (
			'datatype'	=> 'CURRENCY',
			'formtype'	=> 'TEXT',
			'validators'	=> array ( 	0 => array (	'type'	=> 'NOTEMPTY',
														'errmsg'=> 'price_error_empty'),
										),
			'default'	=> '',
			'value'		=> '',
			'separator'	=> '',
			'width'		=> '10',
			'maxlength'	=> '255',
			'rows'		=> '',
			'cols'		=> ''
		),
		'setup_fee' => array (
			'datatype'	=> 'CURRENCY',
			'formtype'	=> 'TEXT',
			'default'	=> '',
			'value'		=> '',
			'separator'	=> '',
			'width'		=> '10',
			'maxlength'	=> '255',
			'rows'		=> '',
			'cols'		=> ''
		),
		'vat' => array (
			'datatype'	=> 'CURRENCY',
			'formtype'	=> 'TEXT',
			'default'	=> '',
			'value'		=> '',
			'separator'	=> '',
			'width'		=> '5',
			'maxlength'	=> '5',
			'rows'		=> '',
			'cols'		=> ''
		),
		'unit' => array (
			'datatype'	=> 'VARCHAR',
			'formtype'	=> 'SELECT',
			'default'	=> 'default',
			'value'		=> array('Item' => 'Item','Hour' => 'Hour','Half-hour' => 'Half-hour'),
			'separator'	=> '',
			'width'		=> '30',
			'maxlength'	=> '255',
			'rows'		=> '',
			'cols'		=> ''
		),
		'recur_months' => array (
			'datatype'	=> 'INTEGER',
			'formtype'	=> 'TEXT',
			'default'	=> '',
			'value'		=> '',
			'separator'	=> '',
			'width'		=> '3',
			'maxlength'	=> '3',
			'rows'		=> '',
			'cols'		=> ''
		),
		'cancellation_period' => array (
			'datatype'	=> 'INTEGER',
			'formtype'	=> 'TEXT',
			'default'	=> '30',
			'value'		=> '',
			'separator'	=> '',
			'width'		=> '10',
			'maxlength'	=> '255',
			'rows'		=> '',
			'cols'		=> ''
		),
		'client_template_id' => array (
			'datatype'	=> 'INTEGER',

			'formtype'	=> 'SELECT',
			'default'	=> '',
			'datasource'	=> array ( 	'type'	=> 'SQL',
										'querystring' => "SELECT template_id,template_name FROM client_template ORDER BY template_name",
										'keyfield'=> 'template_id',
										'valuefield'=> 'template_name'
									 ),
			'value'		=> array(0 => '-- None --')
		),
	##################################
	# END Datatable fields
	##################################
	)
);
$form["tabs"]['shop'] = array (
	'title' 	=> "Shop",
	'width' 	=> 100,
	'template' 	=> "templates/invoice_item_template_shop.htm",
	'fields' 	=> array (
	##################################
	# Begin Datatable fields
	##################################
		'offer_in_shop' => array (
			'datatype'	=> 'VARCHAR',
			'formtype'	=> 'CHECKBOX',
			'default'	=> 'n',
			'value'		=> array(1 => 'y',0 => 'n')
		),
		'is_standalone' => array (
			'datatype'	=> 'VARCHAR',
			'formtype'	=> 'CHECKBOX',
			'default'	=> 'n',
			'value'		=> array(1 => 'y',0 => 'n')
		),
		'is_addon' => array (
			'datatype'	=> 'VARCHAR',
			'formtype'	=> 'CHECKBOX',
			'default'	=> 'n',
			'value'		=> array(1 => 'y',0 => 'n')
		),
		'is_updowngradable' => array (
			'datatype'	=> 'VARCHAR',
			'formtype'	=> 'CHECKBOX',
			'default'	=> 'n',
			'value'		=> array(1 => 'y',0 => 'n')
		),
		'addon_of' => array (
			'datatype'	=> 'VARCHAR',
			'formtype'	=> 'CHECKBOXARRAY',
			'default'	=> '',
			'separator' => ',',
			'datasource'	=> array ( 	'type'	=> 'SQL',
										'querystring' => "SELECT invoice_item_template_id,name FROM invoice_item_template WHERE is_standalone = 'y' AND invoice_item_template_id != {RECORDID} AND {AUTHSQL} ORDER BY name",
										'keyfield'=> 'invoice_item_template_id',
										'valuefield'=> 'name'
									 ),
			'value'		=> ''
		),
		'updowngradable_to' => array (
			'datatype'	=> 'VARCHAR',
			'formtype'	=> 'CHECKBOXARRAY',
			'default'	=> '',
			'separator' => ',',
			'datasource'	=> array ( 	'type'	=> 'SQL',
										'querystring' => "SELECT invoice_item_template_id,name FROM invoice_item_template WHERE is_standalone = 'y' AND invoice_item_template_id != {RECORDID} AND {AUTHSQL} ORDER BY name",
										'keyfield'=> 'invoice_item_template_id',
										'valuefield'=> 'name'
									 ),
			'value'		=> ''
		),
	##################################
	# END Datatable fields
	##################################
	)
);

?>
